
.. _install:


============
Installation
============

Please refer to the [README](github.com/biocontext-ai/knowledgebase-mcp/) for instructions on how to install the BioContextAI Knowledgebase MCP.
